Welcome to our World! Where we serve you cookies to ensure you get the best viewing experience on our site.

Did you know that you can remove censorship board-wide, use our advanced search functions, be notified when new content is posted, join our memberships, set episodes to show in any order you want & more if you are logged into your account?

Register or sign in here: ucp.php?mode=register

Obsession (2025)

Ghosts, Monsters, Vampires, Werewolves, and Witches oh my! Halloween/Horror Movie Collection.
(Satanic, Slasher, Splatter, Cannibal, Occult, Giallo, Chinese/German Underground/Japanese/Korean/New French Extremity Horror etc.)

Moderators: Maskath3, sidolanters, GabrielAlejo2341

Watch on Amazon   Horror Merch   Collectables

Horror, Scary, Halloween Movie Collection.

Obsession (2025)

Post by bunniefuu »

Updated version ~

[grand orchestral fanfare playing]

♪ ♪

♪ ♪

♪ ♪

♪ ♪

♪ ♪

Ever since we...

You're the only person
that I've ever...

Sorry, this is weird.
I-I don't talk like this.

WOMAN:
No, it's okay.

I feel like I'm coming apart.

I think about you
all the time, Nikki.

I try not to...

...you're in every song
I listen to.

You were the only person
who was nice to me

when I moved here.

And at first,
I thought maybe you...

Well, I realized who you are.

And then, after Nana passed,
you were the one that called

even when I didn't have
anything to say

and we just sat there.

So I keep telling myself,
"Don't tell her.

"She's too good.

And she'll... you'll lose her."

But maybe you should know...

...that I would choose you
over everything.

Aw. [chuckles]

-That's everything.
-IAN: No, no. Stop.

-Okay, th-th-that was cringey.
-Oh, my God. I knew it.

-IAN: Way too much.
-I-I'm so sorry.

WOMAN:
I thought that was sweet.

-I thought it was gross.
-BEAR: I-I should've...

-Okay, this time I want you...
-BEAR: No, I...

I'm not doing it again, dude.

-That was so embarrassing.
-IAN: Yeah, yeah.

That would freak...
Th-Th-That freaked me out.

Okay? Nikki would vomit.

You told me to pour
my heart out.

Do you know how vulnerable
I just got?

I underestimated you.

-What if you got her
something nice? -IAN: No, no.

-I'll try that.
-IAN: D-Don't get her anything.

[stammers]
Dude, you got to be less...

way less sappy with Nikki, okay?

She doesn't like that sh*t.
She doesn't.

Flowers, the candy
that she said she likes?

IAN:
Okay.

Thank you.

WOMAN:
What?

Thank you.

WOMAN:
You want me to go?

-Yeah, if-if you want, yeah.
-WOMAN: Oh, yeah, okay. Yeah.

I'm sorry that...
I'm sorry I made you do that.

No. No, it's okay. You're okay.

-No, it-it just...
-It's a fun break.

-Just pretend like...
-You're good.

[chuckles] Oh, my God, dude,
that was so embarrassing.

Can we leave?

Yeah, well, thank God I did it.
That was... that was awful.

Thank you for that.

Have you ever actually, like,
flirted with Nikki?

Invite romance.

-Invite romance?
-Tease her.

-Be playfully mean with her.
-Be mean to her?

Playfully mean, yeah,
but bring up Freaky Nikki.

You want me to call her
Freaky Nikki?

You know she's sensitive
about that.

Be like, "Hey, remember when
you used to get bullied?

Everybody called you
Freaky Nikki?"

She'll be like, "Oh, my God.

"Oh, no, Bear, that was...
that was so long ago.

Don't. Please."

And that will, like,
take her breath away?

Just say,

"Nikki, I think we should grab
a drink sometime."

Yeah, I've grabbed drinks
sometimes.

She always invites you.

-Yeah, exactly.
-I asked you guys not to come

to trivia for one night.

Y-You can't ask her out
at trivia, Bear.

You can't.
I-I'm not gonna let you.

It's a good,
organic time to ask.

I love trivia night.

It's all I have.

I wake up every Wednesday

rock hard,
thinking about trivia.

God, I can't get over
how dumb I just looked.

Y-You can't turn
our weekly gathering

of camaraderie and skill
i-into your... your...

your seven-year-late
promposal, Bear.

Then when do I ask?

Any other time.

All you have is time.

♪ ♪

If she means this much to you--

and I know she does-- wait.

Do it at the right time.

Okay.

Okay, I'll wait.

-I'll do it right.
-Now say it with me.

All you have is time.

-[indistinct chatter on TV]
-[door creaking]

BEAR:
Oh, no.

Sandy?

Sandy?

[Bear breathing heavily]

[quietly]:
Oh, no.

[voice shaking]:
Sandy?

No.

No, no, no, no.

[sobbing]:
Oh, no, no. No, no!

Oh, sh*t.

How did you get into these?

Oh, man.

[Bear sobbing]

Why can't she...

Just...

♪ ♪

[clock ticking]

[phone vibrating]

-Hey.
-NIKKI: Wow, you are so lucky.

Today was so busy.

[chuckles]:
Oh.

I needed a good day off.

Oh, yeah. Definitely.
[chuckles]

-You work so hard.
-[laughs]

You know I do.

Oh, uh, what time are you
showing up tonight?

I want to secure the spot early.

Oh.

Um, I'll...

I don't think I'm gonna
make it tonight, actually.

Aw, Bear, no.

I wanted to see you tonight.

We need your brain.

We got to beat
the Rag Tags this week.

Uh, well, I mean...

I...

I-I don't...
I don't think I can tonight.

I'm just catching up
on some stuff.

I was gonna tell you something.

What?

I mean, should I, like,
tell you now?

Yeah.

What?

Yeah, so I'm putting in
my two weeks.

Really?

How come?

I don't know.

Yeah, we're kind of running
out of time, Bear, so, um...

you know,
might want to skip that stuff

you're working on. [chuckles]

BEAR:
You're right.

-Tonight's the night.
-sh*t!

g*dd*mn it!

Are you okay?

No, I just dropped my crystal
necklace down the drain.

-Oh, sh*t.
-Ugh!

Sorry.

-Why would she even say that?
-[bell chimes, door opens]

Hey, uh, we're closing soon,

so let me know
if you need anything.

-BEAR: Oh, o-okay.
-[indistinct chatter on phone]

-Thank you.
-Right. Yeah, I know.

Ryan was saying that, too,
so I'm not the only one.

MAN [on phone]: Oh, you're
definitely not the only one.

-I know.
-BEAR: Hey, uh, sorry.

I-I do need help.

Um, do you have, uh,
crystal necklaces?

Yeah. Yeah, here,
let me show you.

No, honestly, 'cause that's
what I was saying before.

Like, what? What are you
even talking about?

Oh, my God, that's crazy.

-What?
-No.

Hold on a second.

Um, so this is all we have.

Yeah, each rock has its own

kind of unique energy
and whatever.

So, the amethyst is for
calmness, clarity,

and then the rose quartz
attracts, like, love and sh*t.

What's one that's, like, good...

energy or, like, good vibes?

Probably the citrine.

I mean, it's basically
sunshine in a rock.

Okay. Thanks.

Yeah. Let me know
if you need anything else.

Sunshine in a rock.

Well, no,
'cause yesterday at lunch,

Becca was being, like,
such a... Yeah.

Nikki would hate that.

No, that's what I'm saying.

And then her bringing Ryan
with her?

I was like,
"What are you even doing?"

♪ ♪

Like, really?

You know we don't even like him.

Just so annoying.

Yeah.

Honestly, 'cause that's what
I was saying...

[chatter fades]

What, no crystal?

I like this.

Yeah, well, they've been pretty
popular since we put them out.

You know,
everybody wants a wish.

Well, it's not for me, so...

Okay, well, don't come back
complaining. [chuckles]

Do people complain
about these or...?

Well, they're kind of like
collectibles,

so some people don't open them,
but the people who do,

you know, come back
and complain.

'Cause it's a scam or...?

Hey, man, we're not
scammers, okay?

No, no, I don't mean
that you're a scammer,

but just, like,
why do they complain?

'Cause they're mad

-'cause it doesn't work?
-Yeah, or whatever.

[laughing]: Or it does work and
it, like, ruins their lives?

Or they die
or wish they were dead.

[Bear laughs]

You're good, very good.

Yeah, you could write a review.

-This is gonna be seven...
-[buttons clicking]

NIKKI: Have you ever even been
into a Guitar Center?

-SARAH: No.
-NIKKI: They aren't all tuned.

-So, basically...
-It's not about the guitars,

-and you know that.
-Those teenagers are f*cking

slapping it like a bass,
and the shitty demo strings--

-don't even get me started.
-IAN: Ladies, please.

He doesn't expect them
to be tuned all the time.

-It's...
-[Ian groans]

If you're working
on your book or whatever...

-IAN: Girls.
-...or you're on the clock,

-it would give you
something to do. -Oh, my God.

I never work on my book
when there are customers

in the store,
so why does it matter?

I know, but look, I'm the one
that has to go home

and hear my dad complain
about my friends all night.

I'm just asking you to pretend

-like you're working.
-IAN [whispers]: What?

-Just, like...
-NIKKI: I mean, it's easy

-for you to say...
-No.

...when you're leaving
for tattoo school.

SARAH: It's art school,
and I haven't gotten in yet.

I thought you got into Luther.

SARAH: No, I said
I want to go to Luther.

-NIKKI: Sorry, I didn't...
-SARAH: Still have a shot.

-NIKKI: Good. -SARAH: Sorry.
-[whispers]: Later.

-I-I just don't want you
to get in trouble. -Later.

-NIKKI: I know, babe.
I love you. -SARAH: I love you.

What the f*ck
are you guys doing?

-IAN: Uh...
-Ian's just messing with me.

I look over, and these two
are just... [mouthing]

[laughter]

IAN:
Hey, cut the sh*t.

Hey, can we focus up? This is,
uh, this is very serious to me.

I'm gonna go get some shots.

-SARAH: Great idea, Nikki.
-I'll-I'll come with you.

NIKKI:
Thank you. Thank you.

SARAH [laughs]: What the f*ck
were you guys doing?

[whispers]:
After.

NIKKI:
Four shots of tequila, please.

Um, and anything else?

I'll get a piña colada.

A piña colada?

-Don't make fun of my drink.
-[Nikki laughing]

-What?
-[laughing]: I like a man

who's in touch
with his feminine side.

-Why is that feminine?
-It's not.

I don't like the taste
of the alcohol.

-Yeah, we'll get you juice.
-Wow.

Wait, so what was
the important stuff

-on the phone today?
-A lot.

I did a lot of really
important things.

-That?
-Cleaned.

-Mm.
-I did my taxes.

-I did...
-You watched TV all day.

-Yeah, that's all I did.
-[both laugh]

Bear.

Yeah.

So, uh, I was thinking...

BARTENDER:
Got a card for the shots?

NIKKI:
Uh, yes.

I got it.

Okay, fine. Yes.

You can... But I think...

-Ah.
-I said I got it.

Yeah, you got to be
quicker than that.

Thank you.

You're welcome.

Uh...

Anyway, um...

-I went to the store...
-BARTENDER: Open or closed?

Oh. Open, babe.

I was just trying
to say that I...

you said you dropped
your necklace...

Guys, Sarah just told me
that her dad keeps a g*n

-in the break room safe.
-Wow.

NIKKI:
Are you serious?

Dead serious.

NIKKI:
I feel like he, like,

should've mentioned that
or something.

Not if it's locked away.
It's fine.

Oh, my God, I'm so sorry.
Um, you were saying something.

Yeah, what were you saying?

I was just saying,

um, I... I'll just...
I'll tell you later.

It's fine. I-I got...
I went to this...

Didn't realize we were all
taking a field trip to the bar.

-IAN: Ooh la la.
-NIKKI: All right.

-To... Okay.
-Fine, yeah.

What are we cheers-ing to?

-To Sandy.
-[patrons cheering]

-HOST: Thanks for coming out
tonight. -NIKKI and IAN: Oh.

-HOST: It is trivia time.
-IAN: Mm-mm. All right.

-HOST: And as always...
-Let's get these f*ck, huh?

-All right. -Yeah,
I'm looking at you, b*tch.

-Here we go.
-HOST: ...will win a $100 Visa.

-Why to Sandy?
-[patrons shouting, cheering]

-She died. -HOST: And tonight's
theme is going to be...

-What?
-...early film trivia.

Sandy died.

HOST: Okay, this first one's
a two-parter...

-What?
-Yeah.

HOST: ...and you have to
answer both. Here we go.

Really?

HOST: This animated film
features a blue genie

-that can grant three wishes.
-Bear, I'm so sorry.

Oh, it's okay.

HOST: What is the name
of this movie...?

-[patrons clapping, chanting]
-Guys, settle down.

-NIKKI: Bear.
-HOST: Settle down.

Okay, okay, guys...

Come on, douchebags.
We're going to Greedo's.

No, please.
I just want to go home.

You're saying no to karaoke?

I'm saying no to bad singers
and sticky tabletops

when I just want
to go home and sleep.

All right, so who's gonna dance

when I "Slim Shady"
the whole joint?

[mocking]:
"Who's gonna dance when I

-'Slim Shady' the whole joint?"
-[Bear laughing]

SARAH [laughs]:
Wait, Ian, let's do a duet.

-IAN: f*ck that.
-SARAH: High School Musical?

Sarah will sing. Give me a G.

-[off-key]: ♪ Ah. ♪
-[laughter]

What the f*ck was that?

-No, Sarah sucks.
-SARAH: Shut the f*ck up.

-Can you just please
take me home? -SARAH: Bro.

-I just want to go to bed.
-IAN: Nikki...

NIKKI: I had a long day.
I don't want to go

to the next f*cking bar
with you guys.

IAN: My car's headed
to Greedo's, Nikki.

-SARAH: We could drop her off
on the way. -NIKKI: Come on!

I could take you home.

IAN [chuckles]: You're a real
piece of work, man.

-Thank you.
-IAN: Bear.

-No, Bear, you have to come.
-f*ck that.

-I'm too tired.
-SARAH: f*ck you.

Does anybody have cash?

Uh, I think I have a 20.

Oh, you're an angel.

-Okay.
-I'll pay you back!

SARAH:
You can't have it.

Great, just bought a guy's
heroin for the week.

IAN: You would know
the street price.

♪ You don't know love
till you meet another one ♪

♪ Show you how to grow up ♪

♪ 'Cause you know there's
no need to be someone ♪

["There's No Other" by Felly
playing]

♪ Feeling so numb
when I need somebody ♪

♪ Even though it's not funny ♪

♪ Do you know what it's like
to need, need... ♪

All right, Bear, you ready?

-Good night, guys.
-Okay.

-[Ian grunts]
-NIKKI: Jesus, Ian.

-Bye.
-Get home safe, okay?

-NIKKI: God, you're so f*cking
annoying, you... -Ian.

Get your girl home safe.

Ew. Don't say it like that.

SARAH:
See you later, Bear.

NIKKI: All right, Bear,
let's get the f*ck out of here.

-All right. Let's go.
-IAN: f*ck these losers.

Let's go get f*cked up.

-SARAH: Yeah, Bear, f*ck you.
-BEAR: Let's go.

[music playing quietly
over stereo]

NIKKI:
Sorry about your cat, Baron.

It's okay.

Well, it's not, but...

I don't think it's,
like, hit me yet.

You know you can always
call me when it does.

I know.

It's gonna be weird
not seeing you every day.

Just, I'm not happy there.

I mean, it's just a job, Nikki.

Yeah, well, I want to write.

-I mean, you are.
-No, I...

I feel like I need
a big life change.

I'm not feeling love,
and I want to feel love

if I want to bring the story
to life.

Love?

So it's a romance.

No, it's not a romance.
It's a love story.

[chuckling]:
Isn't that the same thing?

You know, you're the only person

that I get to really talk to
about this stuff.

You are, too.

Especially at work.

You're not a complete
brick wall.

Oh. Um, don't let me forget.

I-I... I got you something.

What?

You'll see.

Ew. No. That...

Why does that make me nervous?

I don't know.

That's an odd reaction.

[crickets chirping]

[car approaching]

[engine shuts off]

You know, Sarah was asking
about you all day today.

How do you feel about that?

You're asking if I have
feelings for Sarah?

I'm asking how you feel
about Sarah,

and if how you feel about her
is having a crush on her,

then that would be
how you feel about her.

I like her as a friend.

[chuckling]:
God. I figured.

She's so f*cking obvious.

[laughing]:
Yeah, she is.

When I have a crush on a guy,
no one knows.

-Good night.
-[door opens]

-Nikki, wait.
-[door closes]

What?

I was gonna ask you, um...

Uh...

I-I lost my train of thought.

-Good night.
-[laughs] Good night.

Wa... Oh.

Hey, do you remember
in Mr. Lando's class

when, uh, I forgot my mouthpiece

and he was, like, in
a really pissy mood that day

and you told me
you had an extra one?

And then you gave me yours,
but, like...

Bear, Lando liked me.

You were on thin ice, okay?

Good night.

BEAR: Good night,
Freaky Nikki. [chuckles]

NIKKI:
Ew. Don't call me that.

I know. I was kidding.

-You know I don't like that.
-Sorry.

I know. I'm sorry.

[sighs]

Do you like me?

[chuckles]:
What?

'Cause if you do,
now is the time to tell me.

♪ ♪

I...

I think we're good friends.

Okay.

Good. Good night.

BEAR:
Oh, f*ck.

Why?

-What the f*ck?
-[house door opens]

[door closes]

[scoffs]

Okay.

[mumbles]

"One Wish Willow.

Amaze your friends.
You only get one wish."

[ominous melody playing
over tinny speakers]

[melody ends]

I wish Nikki Freeman loved me

more than anyone
in the f*cking world.

[keys jingling]

[engine starts]

BEAR:
What the f*ck?

Oh, sh*t.

Um, hey.

Uh, I just had to pull up
directions.

You said you had
something for me?

Um...

Yeah.

Uh, I-I left it at home.

Okay.

[chuckling]: Um, I can bring it
to work tomorrow.

Oh, okay.

Okay. Good night.

Maybe you want to come inside?

I mean, I did just lose
my cat, Bear.

You lost your cat?

Oh, wait.

Uh, I mean...
I mean you lost your cat.

I'm so sorry.

I'm so sorry for your loss.

Do you... Should we...

Do you want
to come inside or...?

Nikki...

[chuckling]:
are you okay?

Are you okay?

Am I okay because of the cat?

Yeah.

-Yeah, I'm fine.
-Why don't you come inside,

and we can have some drinks
and talk about your cat.

Yeah.

I'm sorry. Yeah.

[chuckling]:
Nikki, I'm confused.

-I think you're drunk.
-No!

I'm not act...

Wait, what the f*ck?

Nikki, what the f*ck?
Are you okay?

I'm acting so weird.

[laughing]:
This is so weird.

-[laughing]: What the f*ck?
-[Nikki laughing]

No.

-Why are you...
-No. No.

-What are you do...
-Come on.

-Come on. Come on.
-What the f*ck?

NIKKI:
Actually, no.

[laughing]:
What are you doing?

I know what you're trying to do.

[Bear laughing]

-[laughing]: What the f*ck?
-[Nikki laughing]

Nikki, no.
Why are you getting in my car?

Let's go to your place.

You are honestly
freaking me out.

Oh...

God, no.

I have never seen you
act like this before.

What the f*ck is wrong with you?

I must be...

pretty f*cked up.

Yes, I know, which is why
I think you should go home...

[chuckling]: ...and we'll
pick this up tomorrow.

Can't do that.

Uh...

I just don't know
if I can be alone right now.

Why?

NIKKI:
My dad's dying.

[Nikki sobbing]

Nikki, no.

-I'm so sorry.
-[crying]: I just took one step

inside my house, and I couldn't.

[continues sobbing]

[sniffling]

Can we go, please?

Where do you want to go?

Wow.

Yep. [sighs]

This is it.

It's, uh...

It's bigger
than your last place.

Yeah. Um, it was Grandma's.

I got to keep it.

[sighing]:
Oh, my God.

♪ ♪

It smells like you.

What do you mean?
Does it smell bad?

No. No, just you.

It's nice.

I like it here.

BEAR: Let me know if you need,
like, water or towels

or, I don't know,
Advil or something, okay?

-I'm sorry I was weird earlier.
-No.

No need to apologize.

Just, um...

take all the space or time
that you need.

Okay?

Good night.

NIKKI:
Wait.

♪ ♪

Yeah?

Can you sleep with me?

Please?

-Um...
-Please. I just...

I'll get in my head all night
and stare at the ceiling.

Please?

Y-Yeah.

Yeah.

[takes off shoes]

Are you okay?

Given the circumstances, yeah.

["Televisions" by Current Joys
playing]

♪ I just want to make you cry ♪

[Bear grunts softly]

[Nikki sighs]

♪ For all those times
you made me cry ♪

God, I needed this.

♪ For all those times
we used to know ♪

-[sighs]
-[chuckles]: Really?

Yeah.

♪ On those television shows ♪

Why?

Uh...

I'm really sorry
about your cat, Bear.

I... I think you got me beat
on that one.

♪ I'm having tele-visions ♪

Wait.

♪ I'm having tele-visions. ♪

[breathes heavily]

What the f*ck?

What the f*ck?! What the f*ck?!

-What? What? What?
-Oh, my God.

-I'm so sorry.
-You kissed me.

I know. I-I...
I thought I saw something.

-What the f*ck was that?
-I don't know.

-I'm sorry. I'm sorry.
-No, no, no, no, no.

-Nikki, what the f*ck was that?
-I don't know. I just...

Can we... Can we sleep?

I'm sorry.

You don't have to be sorry.
Just...

sh*t, you made me feel like
I did something

-you didn't like.
-No.

I'm sorry. I'm sorry. I just...

-I thought I saw something.
-Oh, my God.

-You scared the sh*t out of me.
-It was a panic attack.

What? [panting]

It was a panic attack.

-Really?
-Yeah.

[sobbing]:
I'm just so lost.

It's okay.

[clock ticking]

♪ ♪

[taps keyboard]

[typing]

[tapping key]

[sighs]

[chuckling softly]

What were you doing?

I-I was just going
to the bathroom.

Can you lay with me?

I don't know, Nikki.

Please?

♪ ♪

[inhales deeply]

-[bird calling in distance]
-[exhales]

♪ ♪

[floorboards creaking]

[sniffs]

[flies buzzing]

NIKKI:
Oh, no.

No, you're supposed to like it.

Nikki, you...

It's a memorial. I...

BEAR:
No, it's f*cked up.

NIKKI: Well, I don't know
if it's f*cked, Bear.

BEAR:
No, it is.

NIKKI:
Is that good?

BEAR:
Why would that be good?

[music playing faintly
over speakers]

[guitar strings tuning]

[entry bell chiming]

-Oh, Nikki.
-What?

Show me the plug-in keyboard
that isn't working,

'cause I don't want to give
some Karen an excuse to...

-Carter. Don't say "Karen."
-What?

CARTER: No, but isn't that
someone that says no?

NIKKI: No, Carter.
You can't say that.

-CARTER: Oh. Why?
-NIKKI: There's people inside.

-Just... Okay, let's go.
-Yes.

-Go. Go.
-[muttering]

Okay. Okay.

What the f*ck?

What the f*ck happened
last night?

Okay, okay, okay, okay.

You're not gonna believe

the crazy f*cking night
that I just had, dude.

-You f*cked Nikki, you dog.
-No. No.

-What did you say to her?
-No, I didn't f*ck her, dude.

I just saw you come in together.

-Yeah, well...
-Did she sleep over?

By the way, you got to clock in.

-Ian.
-What-what are you afraid of?

Sarah?

Just pretend like we're...
Laugh.

[both forcing laughter]

Yeah.

I think Nikki is going
through something.

-What?
-I don't know, dude.

She was acting
super f*cking weird.

Like, she would, like...

Like, what? Is she okay?

No.

-Did she tell you what's wrong?
-Like, sort of,

but I think there's more.

Well, what the f*ck is it?

-I'm gonna let her tell you.
-Don't f*cking bring it up

and then don't tell me,

-you f*cking as*h*le.
-Her dad has cancer.

-Really?
-That's what she told me.

Her dad in Washington
that she doesn't care about?

It still hurts, I guess.
I don't know.

-Yeah. Yeah. -But I think
it's more than that.

Like, I think
she's having, like,

a mental breakdown or something.

Like, she would, like,
freak out,

and then she would, like,
snap back to happy.

What the f*ck?
Are-are you joking?

She started kissing me
and then crying.

It was really f*cking weird.

Uh, so you told her
how you felt, and then...

I didn't tell her.

What?

-I didn't tell her.
-You...

-Sh-She was kissing you?
-That's what I'm saying.

And how exactly does that
make f*cking sense?

I don't know, dude.
I think she needs serious help.

And sh... and she was crying?

Yes, and then she would, like,
snap back to normal.

It was terrifying.
It was, like, psychotic.

I don't know. And then...
and then she wanted me to, like,

cuddle and sleep with her.

-Did you?
-No.

-'Cause that'd be f*cked up
if you did, bro. -I didn't.

-I was sleeping on the f*cking
floor. -Don't f*ck with me.

She was freaking me out.

You think she was
on Molly again?

I mean, I don't think...

-Maybe.
-Yeah, dude.

It sounds like she was
on f*cking Molly.

[sighs] Yeah, maybe.

-I'm gonna go talk to her.
-Wait, wait.

Is she still looking?

Yep, totally. She's looking.

-Don't be weird.
-Can you just

chill the f*ck out
and clock the f*ck in?

CARTER: Baron, I'm gonna
need you to play "Moon River"

-on the piano for that...
-NIKKI: Hey, Bear.

CARTER: ...14-year-old
sh*t brick in keyboards.

IAN:
Hey, Bear.

CARTER: Sarah, honey,
will you stock up percussion?

All right, come on, guys.
Big day today.

We're gonna have a rush.

[crickets chirping]

BEAR:
Okay.

IAN: Dude, I need a f*cking
drink after that sh*t.

BEAR:
That was insane.

-NIKKI: Told you.
-SARAH: I'm pouring myself a...

-[Nikki yawns]
-SARAH: I'm calling it a night.

-BEAR: Um...
-IAN: Have a good one.

-SARAH: Thank you.
-IAN: See ya.

-SARAH: Get home safe. Bye.
-Uh, Nikki,

I don't know
if I can take you home today.

I know.
I'm just grabbing my purse.

Oh.

IAN:
Ready?

NIKKI:
Yep.

Uh, excuse me.

-Are you gonna take her?
-Yeah.

I'm gonna take her.

-Okay.
-Good.

Trust me.

Bye, guys.

IAN:
See ya.

[engine starts]

BEAR: I looked at, like,
three different websites,

-and, like...
-IAN [over phone]: Yeah.

BEAR:
I think she was...

-IAN: Yeah.
-BEAR: Did you talk to her?

-IAN: Yeah, I did.
-BEAR: What did she say?

Uh, sh-she's... she's good.

Everything's good.

She wasn't, like,
looking at you or anything.

She was staring at me, and...

Maybe, but I-I was just
talking to her.

She was looking at both of us.

It looked like we were
talking about her,

so that explains it.

You guys walked in together.

-I'm gonna just call her.
-Uh, maybe don't.

-[knocking at door]
-Don't do that.

'Cause, you know,
we're just... we're chatting.

-Just...
-Hold on.

It sounds like you're
gonna talk to her.

-Bear...
-[phone beeps]

-NIKKI: Hey, Bear.
-Oh.

-[chuckles]: Hey.
-I had to shower,

and I didn't know what to wear.

For what?

So, I'm really sorry
about last night. I, um...

-No. -Ian told me
you were freaked out.

I'm just glad I could
be there, I guess.

Yeah, um, so I probably
shouldn't have taken anything.

So...

I was on MDMA.

-Right.
-And... wasted.

[chuckles]:
That's okay.

Do you...

remember...

stuff?

Some of it. I mean...

So, if I was weird, that's why,
and my dad made me a mess,

and so I did things I probably
wouldn't have done otherwise.

And I'm not saying
that you took advantage of me.

Nikki, I didn't know
you were on drugs.

That's what I'm saying.
I'm not saying that.

-Not saying what?
-You took advantage of me.

I don't think... I didn't.

I know. That's why...

-I'm saying you didn't.
-Okay.

Good.

I just, um, don't like to...

I really like what we have,

and I want to be honest
about some things,

and it's really important
for me.

It's okay.
Um, you know, I-I get it.

I get it.

I know you like me, Bear.

♪ ♪

[stammers]

No, I...

Why? Do you like me?

Would it freak you out
if I said yes?

[chuckles softly]

How long have you felt that way?

It's just happened over time.

Started during Christmas, and...

I don't know, it just...

Then, last night,
I saw what we could...

Do you have feelings for me?

Yeah, I do.

♪ ♪

[voices muted]

♪ ♪

♪ ♪

♪ ♪

And I wrote, "In a band,"
and then she made me change it.

-Yeah.
-b*tch. [laughs]

And then you leaned in,
and you whispered...

BOTH:
"I'll be in your band."

[both laugh]

Yeah.

How's your dad doing?

-Can we not talk about that?
-[cell phone vibrating]

Okay.

Um...

so what do you want to do?

I mean, I never really asked.

Well, that's not all your fault.

I mean, I'm kind of private,
I guess.

You guess?

I've been told.

-By who?
-Ian.

You, actually.

You told me that once.

I did?

You called me a closed book.

Well, I guess the good thing
about a closed book is

I get to read it from the start.

[chuckles]

Maybe a food critic
or something.

You put ketchup on your steak.

I'll come in,
and they'll be like,

"Hey, aren't you the food guy?"

And I'll say, "Please,
call me Three-Bite Bailey."

And then they will serve me
a four-course meal,

and I'll pull out my wallet,
and they'll say,

"No, no, no, sir, please,
tonight, on the house."

And then I get paid.

Is that how that goes?

-I actually don't know.
-[both laughing]

Okay, my little food critic,

what's the verdict
on this bread?

-This bread?
-Mm-hmm.

Oh.

Well...

Hmm. Slightly stale, but the
butter makes up for that sh*t.

-Profound.
-That'll be a hundred dollars.

[laughs] Well...

-[cell phone vibrating]
-Sorry.

It's the second time
he's called.

I'll be right back.

-What is it, dude? I'm busy.
-IAN: Oh, busy doing Nikki?

What do you want?

Okay, so, um...

-What is it?
-[Ian stammers]

I'm not gonna tell Sarah
about this,

because I don't want
to spread drama.

I looked into Nikki's dad
having cancer,

and he's healthy as a baby.

He's been to work,
like, every day.

Why would she lie
about that, Ian?

I don't know. For attention.

I called the hospital
she told me about,

and they didn't even know
who I was talking about.

Look, you know I always
got your back on this stuff.

Apparently, Nikki and Sarah
had a conversation about you

that-that day you weren't in,

and, uh, Nikki said
she just thought of you

like her little brother
or, you know,

and she, like, friend-zoned you.

And-and-and look,
that may suck to hear,

but I just think
you got to know because,

I-I don't know, I think she has
some kind of ill intentions

or something freaking mental
is going on, man.

And maybe Sarah's jealous
and made that up,

but, like, even if you take
that out of the equation,

this is strange, dude.

It's like Nikki snapped
into a different person.

Sh-She's all of a sudden
infatuated with you.

♪ ♪

Everything okay?

[voice trembling]:
Nikki, do you...

What?

Never mind.

I have something for you.

-What is it?
-Um...

What is it?

Open it.

It's a... it's a tiger's eye.

-Wow.
-It was my mom's,

and then it was mine.

It's supposed to bring you
confidence and willpower, so...

now you can be a food critic.

Why are you giving it to me?

Bear, I love you
so, so, so, so, so much.

I don't think I could live
without you.

You love me more
than anyone in the world?

[chuckling]:
Yes, more than anyone.

Nikki.

Yeah?

Does your dad
really have cancer?

♪ ♪

No.

[chuckling]:
No, no, no.

What?

No, no, no,

-no, no, no, no, no.
-What?

-Don't do that!
-Nikki. [stammers]

-I thought we were having a
nice date. -[patrons murmuring]

-We-we are. We are. Sit down.
-Why does it matter?

-I thought we were having
a nice date. -We are. We are.

-We are. We are.
-[Nikki crying]

It's okay.

We are. We are.

Then why does it matter?

It doesn't matter to me.

[grunts] Oh, yeah.

[grunting, moaning]

-[Bear grunting]
-Yeah. Uh-huh.

[moaning]

[breathing heavily]

-Oh, that was amazing, baby.
-Yeah.

Yeah.

[takes deep breath]

Nikki?

-NIKKI: Go back to sleep.
-[Bear gasps]

BEAR:
Nikki.

What are you doing?

What are you doing?

[whispering]:
Watching you sleep.

You're so cute when you sleep.

Wearing my sweater, huh?

Smells like you.

-Can you come back to bed?
-No, no.

-Nikki.
-No.

[crying]:
I don't like my dreams.

[sobbing]

I feel like you don't love me
as much as I do.

Like it's not mutual.

No, I... I do.

-Just come back to bed.
-[sobbing continues]

Please?

[sobbing stops]

[crying]:
Go back to sleep.

[Nikki sobs softly]

-Why don't you love me?!
-[gasps]

Nikki? Nikki, where are you?

[rapid, trembling breaths]

What?

Nikki, what are you doing?

Nikki.

No, what-what do you
want me to do?

For Sandy, okay?

♪ ♪

Stay!

[insects trilling]

[birds chirping]

What the f*ck?

-Morning.
-NIKKI: Morning.

[clears throat]

Um...

Yeah?

Did you cut my hair?

Yeah.

Let's not do that.

Okay.

Packed you a lunch.

Oh.

[Nikki laughs]

Oh, oh, can-can we talk
about last night?

[sighs] I know.

I know. I know.

It was kind of weird.

Right? [chuckles]

Yeah. I'm so sorry.

Okay, good,
'cause if I'm being honest,

it was kind of terrifying.

Oh, my God.

I'm so sorry.

I had a bad dream, and I just...

-You what?
-How's this?

Not great.

Okay.

-Listen, Nikki.
-Come here.

-I think...
-Come here.

Listen.

[Bear's breath trembling]

I love you.

I love you, too.

-So, so, so, so...
-Okay, okay, okay, okay.

Good. Good.

So, will you promise me
something?

Yes.

No more weird stuff.

All right?

No more watching me
while I sleep

or, like, moving weird.

-Okay.
-All right?

I super promise,

and I'm so sorry
that it even happened.

Okay.

-Okay.
-So...

-we're good.
-We're good.

[chuckles]:
We're good.

-Great.
-[laughing]: Great.

[both laughing]

We're good.

All right.

Oh, God, I'm gonna miss you.

I wish I was scheduled today.

[Nikki sighs]

No, no, just enjoy your day off.

[Nikki sighs]

Maybe I can pop by.

No, no, just make yourself
at home.

NIKKI:
Love you.

BEAR:
Love you.

♪ ♪

[tape tearing slowly]

[grunts]

NIKKI: If you're having trouble
with the door,

maybe you should just stay home.

No, I got it.

-[grunts]
-[door creaks]

Bye, Bear.

[door closes]

[liquid trickling]

♪ ♪

[music playing quietly
over speakers]

♪ ♪

SARAH: Why-why is everyone
so entitled these days?

Like, people have no patience.

It's... it was so clear
I was busy,

and they won't stop
pestering me.

What the f*ck is that?

Inside joke.

SARAH: You going
to Ian's thing tonight?

First I've heard.

Well... [scoffs]

"Well," what?

I heard what you told Ian.

About what?

About Nikki.

How she friend-zoned me.

I don't know what Nikki said
in the past, but...

I mean, we literally
talked about it once.

I just think that it's weird

how you two are dating
all of a sudden.

Like, super dating.

I don't know, Sarah.

Look, I couldn't care less
whatever game Nikki is playing.

I just don't want you
to get hurt and...

-What is your problem
with Nikki? -No, and if

Ian's gonna spread my sh*t,
then you should know,

-Ian and...
-CARTER: Honey.

We got another one.

SARAH:
God, I'm nervous.

-[paper rustling]
-Please, God.

Please.

[Carter and Sarah sigh]

SARAH:
No.

CARTER: Well, you got to get in
somewhere, or else...

-SARAH: I know.
-CARTER: You know?

Okay.

Get back to work.

[Sarah sighs]

[sighs]

This is what I get
for being such a f*ck

in high school, huh?

Is that your... the last one?

No, one more.

Luther.

♪ ♪

You can give me a tattoo
without a school.

Thanks.

It has to be small,
in a hidden location.

[Sarah laughing]

Your lunch smells weird.

-Oops. [laughs]
-Jesus.

"My little food critic."

-What are you doing?
-"My little food critic."

[Sarah laughing]

Well, what's the verdict on cat?

What?

What does that mean?

"What's the verdict: cat?"

[Sarah laughs]

Bear, what's that mean?

That is so f*cking weird.

[Sarah laughing]

Bear, what does that mean?

What?

Bear, what is it?

What the f*ck is wrong with you?

Are-are-are you okay?
Bear, what...

-Oh, my God.
-[retching]

-Bear, are you okay?
-IAN: What's going on?

-SARAH: Oh, my God!
-IAN: Bear, what the f*ck?

-SARAH: Dad!
-IAN: No, I can't do that.

-I can't look at that.
-Bear, what does that mean?

BEAR:
Inside joke.

-Baron.
-[Bear grunts]

Yo, can I get a...
can I get a ride home?

Where's your car?

Uh, I had to Uber today.

"Check engine" light.

-I was gonna run some...
-What, run some errands?

Come on, we're neighbors.

IAN:
So, uh...

we gonna talk about
you and Nikki?

BEAR:
What about it?

You come to me saying
Nikki's having, like,

some f*cking crazy
mental breakdown or something

and that she needs to get help,
and now you're acting like,

"Oh, no, no, we're in love.
She's f*cking fine.

-Everything's perfect."
-She was on drugs.

Nikki is literally fine.

Okay, can you just please
break this down for me?

She's lying about cancer.

I'm not gonna
break this down for you.

And now she's sleeping over
all the time.

I don't want to break down
our relationship.

Lying about her dad.

I mean, you have to admit
that's crazy.

Oh, and by the way, I heard
you're having a party tonight.

-Don't change the subject.
-Why didn't you invite us?

Oh, oh, so now you're an "us"?

Well, why didn't you invite me
to the party?

Don't-don't change the subject.

I'm not gonna invite you two
to my place.

Why not?

Because.

It kind of looks like Nikki's
going through something,

and... it kind of looks like

you're taking advantage
of the situation.

-Oh, f*ck you, dude.
-And I say it with love, bro.

-I'm saying it with love.
-Come on, she is all over me.

I'm on your side,
but it's a bad look.

What do you think this is gonna
look like to other people?

Why-why are you trying
to ruin something good?

Carter even said something.
It's a bad look, man.

That is so unfair, dude.

She's the one
who won't leave me alone.

Fine.

You want to come over tonight?

I don't know, maybe.

Nikki can't come.

[chuckling]:
Dude.

No, Nikki can't come.

-It's a boys' night.
-Great.

I'm sure she'll be fine with it.

I'll text Sarah not to come,

and that should be
completely fine,

because if the relationship
is healthy

and it's not built
on some codependency,

dad dying, not dying,
what-the-f*ck-ever,

then she should be completely...

she should have
no f*cking problem

with you coming
to a boys' night.

-I'm totally fine with it, too.
-You are fine with it.

[engine shuts off]

Nikki, I'm very upset.

You can't cook the cat.

You can't cook the cat, okay?

I'm going to hang out
with Ian tonight.

Gonna hang out with Ian alone.

[ominous melody playing
over tinny speakers]

[melody ends]

[unzips bag]

[chuckles]

♪ ♪

Okay.

[line ringing]

MAN [over phone]:
Hello?

Um...

[chuckles]:
Hello?

Hey.

What's up?

Um, is this...

One Wish Willow?

Yeah.

Uh, o-okay. Um...

O-Okay, I-I was...

calling to see
if there's a way I can...

alter a wish.

You'd like to cancel your wish?

No. No, no, no.

Uh, it's okay to keep the...

I-I just want to know
if I can, like...

[chuckles] alter it a little.

I'm sorry.
We don't really do that.

No?

If you have any questions
about how the wish works

or if you read the back
of the box...

I mean, is it even real?

Yeah, it's real.

No, I-I know that the...

Is her love real?

Just because
you chose this for her

doesn't make it less real.

Okay.
Then I would like to cancel.

You'd like to file
a cancel request?

Yes. Yeah, a-a cancel request.

-We don't really do that.
-What?

We don't really do that.

You were just making it
sound like

I could put in a request.

I was just guessing
your intention, man.

What the hell?

Well, what can I do, then?

Nothing, really.

So she's just f*cked forever?

Well, yeah.
I mean, as long as you live.

As long as I live?

♪ ♪

I mean, when-when you die,
the wish will go away.

You're sure there's
nothing else I can do?

Yeah.
I mean, as long as you live.

Sounds to me like you have
a moral obligation

to be there for her.

Okay, but w-wait.

Sh-She does this thing
where she's, like...

freaks out.

Wh-What is that?

Do you want to talk to her?

What? Who?

-[screaming over phone]
-Do you want to talk to her?

Who is that?

Nikki.

[Nikki screaming over phone]

MAN:
Do you want to speak to her?

-[phone beeps]
-[screaming stops]

[trembling breaths]

[tape tearing]

[door creaking]

-Oh, sh*t!
-Bear.

-Hi. Hi.
-[sloshing]

-Hi.
-Hi.

-What happened?
-What?

What the f*ck happened?

I don't know what to do.

Do you need, like, a...

Oh.

-Um...
-God, I...

-It's okay.
-I'm disgusting.

Did you have
a seizure or something?

-What happened?
-I...

ate a bug or I have
a stomach bug, I think.

Okay, um, I don't know
what to do. Um...

I was just waiting for you
to come home.

-Oh, my God, I'm disgusting.
-Uh, maybe you should...

I... I'll shower.

Let's-let-let's go
to the shower, okay?

I-I'll clean it up.
I'll clean it up.

It's okay. You can...

I'll go shower.

-Or... Yeah.
-And I'll clean it up.

I promise.

Um, you can...

-[door slams]
-Oh, sh*t.

-I'll clean it up, baby!
-[shower curtain opening]

It's okay.

[shower water running]

Um, Nikki?

We talked about this.

Did you cook the cat?

Nikki, you can't do that.

I am very upset about that.

Okay, honey.

Hey, listen, um...

Ian invited me
to a-a boys' night tonight.

-[loud metallic squeaking]
-[shower water stops]

[water draining]

Okay.

So I-I think I'm just
gonna go to that,

if that's okay with you.

Go to the boys' night?

Yeah.

I can get dressed
and go with you.

Oh, man.
That-that sounds great.

Yeah, let me finish showering,

-and I'll go with you.
-It's-it's just that, um...

Ian said it was a boys' night,
so I think maybe I'll just go.

-[clattering]
-[Nikki screaming]

Are you okay?

-[screaming stops]
-[heavy, trembling breaths]

[laughing]:
That's so weird, 'cause...

Sarah was telling me
that she's going.

Really?

Okay, well, I'll just
stay here, then.

-I mean, if-if Sarah's going...
-No, no, no.

-If you wanted me to go, I...
-No, you know what?

I-I think you should come.
I-I really want you to come.

-No!
-[gasping breaths]

[sobbing]:
If you wanted me to go,

you would tell me to go!

I knew you were gonna bring her.

I f*cking knew it.
She-she guilt you?

BEAR: She didn't guilt me.
Shut the f*ck up.

You couldn't be without her
for three f*cking hours?

Sarah invited her.

-What was I supposed to do?
-Sure.

You told me you weren't
going to invite Sarah.

-Sarah did nothing wrong.
-Neither did we.

♪ Yeah, I think I played it
pretty cool with you, babe... ♪

No weird sh*t.

Hey. Keep your f*cking hands
off my mom's china, as*h*le.

Hey.

Okay, it's my turn. My turn.

Ooh, someone's getting
f*cked up.

Okay. "Choose someone to drink
every time you do

for the next three rounds."

Ah, yeah, you're going down
with this ship.

-Man, here we go. Cheers.
-[sighs]

Uh, "Switch seats with anyone."

Baron, I want to sit
next to Nikki.

-GROUP: Ooh.
-No.

-Uh-oh.
-It's okay, baby.

Oh. No, it's okay.

I showered, baby.

Geez, Bear, what kind of spell
did you put on her?

[laughter]

-[Nikki laughing loudly]
-[other laughter dies down]

NIKKI:
So true. [laughs]

SARAH:
Nikki, it's your turn.

Oh.

"The air was charged by the
distinct call of a night bird.

"His face was obscured,

"but I knew he was looking
at my chest,

"each side stretching,
recently mature,

"to different sizes.

"'And so, come lie with me

"like the old woman taught us
when we were children,' I said.

"He closed the door
and leaned against it.

"'You're not my wife, Gretel,'
he said.

"'I'm more than your wife.

"I am your sister.'

"Hansel flinched and reached
for the door handle.

"I knew he would not
leave this place.

"He would relent
and choose to be inside me

"like he had many nights before.

"If not, I would fillet
his meaty forearm,

"roll it like a stick
of licorice

"and insert the flesh
between my legs.

"Hansel is my soul.

"A love only the branch
of a willow tree could conjure.

Brother, you will be
inside me tonight."

New book I'm working on.
I don't have to drink.

[sighs]

REGGIE:
It's your turn, Joe.

I switched spots with Baron,
so it's his turn now.

Oh, sh*t. Okay.

Um...

"Kiss the person on your left."

♪ ♪

-[loud thud]
-[wood creaking]

[quiet chatter]

[footsteps]

[chair scraping loudly]

[Nikki sighs softly]

[softly]: No one on this earth
will ever comprehend

what it feels like
to love someone

as much as I love you.

[sighs]

[loudly]: And everyone
in this room will die

never feeling the strength
of connection

I have felt with my Bear.

Nikki...

are you okay?

I'm just kidding, guys.

[chuckles]

I'm just kidding.

[laughing]

Come on, it's a joke.

I'm just joking.

Okay, fine. I'm not joking.

Deal with it.

IAN: Anybody, uh,
want any, uh, Jell-O shots?

I'll take one.

Thank you, Reggie. Yep, cool.

-IAN: Any other takers?
-[Nikki gasps]

[Nikki screams]

It's not me! It's not me!

-[frantic chatter]
-It's not me!

[partygoers screaming]

[frantic chatter]

Bear, she needs your help!
Bear, help her!

No, no, no. You got to...
Bear, get her to the hospital.

-[frantic chatter]
-I'm so sorry. [laughs]

IAN: Bear, she needs
to go to the hospital.

Just stand still
for a second. Bear.

SARAH: She needs to go
to the hospital.

-God, Ian.
-IAN: Bear.

Bear, are you f*cking
listening to me? Get up.

-NIKKI: Bear, let's go!
-IAN: Get up, as*h*le!

♪ ♪

[voices muted]

♪ ♪

♪ ♪

[Bear takes deep breath]

Where you going?

Just going
to the bathroom, Nikki.

Okay?

Okay?

Can I stand outside?

-Why did you do this?
-I know.

-Why did you act like that
tonight? -Sarah's dirty.

You... Nikki.

-You're scaring everyone.
-Bear...

I don't know why I did it.

-I just get nervous.
-You hurt yourself.

-I'm sorry.
-Look at your face.

I know Sarah likes you.

That... That's...

-What?
-That's just...

God, f*cking everything
was normal!

Everything was good.

You were so... I'm sorry.

I'm sorry, I'm sorry, I'm sorry.

Look, you're so beautiful,

and you were...
and you-you are normal,

but this is not...
this isn't okay, Nikki.

Do you like me?

What? I...

-Bear, I love you.
-No, no, no, no.

No, no, no, no, no, no.

Do you... do you like me?
Do you even like me at all?

Is-is Nik... is Nikki happy?

Does Nikki like me?

Yeah.

-I'm your Freaky Nikki.
-No, no.

No, no, no. Nope.

-No, no.
-Where are you going?

I'm going to the bathroom,
Nikki.

-Can I do that?
-Can you tell me you love me?

This is all I've ever wanted.

Me, too.

-No, it's not.
-Yes, it is.

Yes, it is, Bear.
It's always been you.

I want this to work so bad.

-It can. It can.
-No, no. No, it can't.

-Yes, it can.
-Okay. Okay.

Then, uh, you need to go home
for one night or...

a-a-and we need to, like, take
some space from each other.

-Okay, w-we have to...
-[wailing]: No...

-God, Nikki, no!
-I don't want space.

We have to take space
from each other, Nikki!

It's normal for couples
to have some f*cking space

-from each other!
-I don't want space! Please.

-Just tell me what I can do.
-Just be normal like...

-I can be normal!
-I just...

God, I just want you
to be Nikki.

[sobbing]:
I can be Nikki.

-Just be Nikki.
-I can. I can.

I can.

I'll be anything
you want me to be.

No, don't say that.

Anything you want me to be.

No, no. You won't listen.

Nikki wouldn't say that.

I just want you
to act like Nikki.

-I'll be... Let me be Nikki.
-You're not being like Nikki.

I can be Nikki!

♪ ♪

I'm sorry.
I'm sorry. I'm sorry.

[voice trembling]:
I'm sorry.

I can be Nikki. I can be Nikki.

I love you. I'm sorry.

It's not real.

What do you mean?

[crying]:
It's not real.

I love you

in every reality, Bear.

[sighs]

I love you, too.

-[indistinct, distorted speech]
-Whoa, whoa.

What the f*ck?

-Nikki, stop.
-[indistinct, distorted speech]

No, please.
Nikki, you're scaring me!

Don't be scared, baby.
Don't be scared.

-I-I would never hurt you.
-[Bear breathing heavily]

-I'm sorry.
-Stop!

Nikki, you're scaring me!

Okay.

Hey. Hey. Hey.

Why don't you take the bed
for yourself tonight,

and I'll just go sleep at Ian's,

and I'll come back
right in the morning?

-Okay.
-[Bear breathing heavily]

[clattering]

-Nikki, what are you doing?
-I don't need your attention.

-[Nikki groans]
-Nikki, what are you doing?

[clattering stops]

Well, if I have the bed
all to myself tonight,

I'll lay there warm,

until slowly I feel cold,

like I walked into a freezer.

My hands will feel like
they're full of sand,

like when you lay on them wrong.

And that feeling will slowly
spread across my entire body.

You're still in my heart,
but you're slipping.

Any thought of pain or regret

will slip away
like a chemical switch.

And even though it's quiet
in the room,

somehow it gets even quieter.

-[shuddering]
-It's not painful.

You just let go
of everything you once were.

And then there's nothing.

It's not darkness.

No, sweetie.

Darkness is a color.

There's just nothing.

Or you could stay.

[trembling breaths]

Yeah.

[crickets chirping]

[cell phone dings, vibrates]

[clock ticking quietly]

[whispers]:
Nikki.

[clock ticking quietly]

♪ ♪

♪ ♪

-NIKKI: Bear.
-[gasps]

I'm just getting water.

k*ll me, please.

What?

She's sleeping.

It's me.

-You are you, Nikki.
-Shh.

[whispers]:
Please don't wake her up.

[voice trembling]:
Just k*ll me.

What would be so bad?

What's so bad about
being with me?

I've never been with you, Bear.

Just k*ll me, please.

[crying]:
Please, please, please, please.

[knocks on window]

Hey.

[sighs]

I didn't know
you still did this.

Did what?

Parked at Franklin and chilled.

Oh. [chuckles]

I don't really do this anymore.

So, what the f*ck
is up with Nikki?

Well...

She hasn't really told
many people this, but...

her dad is dying.

So, you know, it's pretty...

Isn't she, like,
not close with him at all?

No, they're close now, so...

it's, you know, painful.

I thought she hated her dad.

No, she doesn't.

I really do hope
she figures it out.

Uh, she seems pretty f*cked up.

And I-I also don't think
it's right that she's

leaning on you,
especially since her and...

I don't mind
being there for her.

No, but that's not
your responsibility, Bear.

She needs therapy.
It's-it's not right.

And I don't think it's okay

that she's taking
advantage of you.

I don't think she's...

taking advantage of me.

[scoffs softly]

Hey, so I, um...

I got my letter.

Your letter from Luther?

Yeah. My last chance.

Figured we could
open it together.

[chuckling]:
Oh, sh*t.

Maybe my dad will let me tattoo
"successful daughter"

where his hairline's
supposed to start.

[both laughing]

Um, can I pay you to do that?

We can take him in his sleep.

Well, I have sleeping pills
in my pocket.

We can literally
take him tonight.

["Kids" by Current Joys
playing quietly]

Do you want to open
this thing or...?

I-I need to tell you
some things.

What?

f*ck. I promised Ian

-I wouldn't tell you this.
-Tell me what?

Bear, Ian and Nikki have been
hooking up on and off

for like two years.

It's super casual
and not romantic.

He thinks that she's dating you
to get back at him.

But even if she's not...

...it's kind of a shame,
you know?

I think you need someone...

more chill.

Like you?

Well... [chuckles softly]

I mean...

I was to your left.

You-you were what?

-In the game.
-Oh.

I was to your left. [laughs]

You were supposed to kiss me.

-[Sarah screams]
-[rhythmic thudding]

-[Nikki grunting viciously]
-[horn honking]

[gasping]

[thudding and honking continue]

[thudding and honking stop]

[trembling breaths]

[Nikki panting]

[Bear grunts]

NIKKI: I'm so sorry
you had to see that, baby.

But it is kind of your fault.

Just remember
that you wanted this.

But I'm so happy you did.

I'm so happy you did, baby.

Oh, no.

No. No, no, no, no, no.

Oh.

No, no, no, no, no, no.

Honey, breathe, breathe.

It's okay. It's okay, honey.

I've got you.
We need each other.

-[Bear whimpers]
-We need each other.

But you're gonna have to
help me get rid of her body.

-No. No. No.
-Yes. Yes, honey.

Honey, I know.
I know, I know, I know, I know.

Listen.

This is all your fault.

Sarah's your fault.

You wanted this.
You wished for this.

But, baby, we can fix this.

I'll fix this with you.
I'm not going anywhere.

I'm not going anywhere.

[both grunting]

[soft clattering in other room]

She's ready, baby.

Why don't you go home?
I'll take it from here.

[engine idling]

[engine shuts off]

♪ ♪

[bird calling in distance]

[paper rustling]

♪ ♪

[screams]

[breathing heavily]

[screams]

[sobbing]

♪ ♪

-PATRON: Jesus, dude.
-What the f*ck?

No, no, no. Oh, no.

Oh, sh*t.

Um, uh, excuse me.

Where are the, um,
One Wish Willows?

-CLERK: What?
-It looks like this,

but it's like a... [stammers]

it's like you make a wish
and you break it.

They were right there.

They were over there
in the corner.

The One Wish Willows!

What's a One Wish Willow?

[voice trembling]:
No.

-No.
-First of all, sir,

don't come in here with this.

It is too early.

And second of all,
I'm f*cking with you.

They're right here.
Yeah, yeah, yeah, yeah, yeah.

You made a shitty wish,
and now you want to reverse it,

but you can't come in here
with this energy, man.

Did you call the number
on the back?

What the f*ck is wrong with you?

[scoffs] Me?

How could you sell this
to people?

The box is full
of warnings, man.

-f*ck you!
-Hey, f*ck you, man.

But you don't storm in here
with this energy, man.

I'm sorry.

[crying]: I-I...
Nobody would buy it if they...

I'm sorry.

Oh, sh*t.

Oh, God.

What did you do?

She's obsessed with me.

Oh.

Well, that's not so bad.

No, something bad happened.

[sobbing]

I'm sorry.

-I... I need to reverse it.
-No.

-No, no, no, no, no, no, no.
-I need to reverse it.

Y-You can make a wish.

-I already used my wish, man.
-Oh, please.

Wh-What the f*ck do I do?

Well, maybe...
maybe if someone else

made a wish
that contradicts your wish...

I mean, maybe you could ask her.

I mean, since it's for you,
she just might do it.

Oh, o-or you could die.

I mean, you could k*ll yourself.

You know, I'm just
spitballing here.

[fading]: If you ever want
to jump in with any ideas...

[breathing heavily]

♪ ♪

f*ck.

[ominous melody playing
over tinny speakers]

I wish Nikki Freeman
only loved me as a friend.

[melody ends]

[straining]

f*ck!

[straining]

f*ck. Oh, what the f*ck?

[straining]

God! f*ck! f*ck.

[breathing heavily]

[engine starts]

Ian?

[knocking]

BEAR:
I texted you 50 times.

Jesus Christ, Bear, what the...

So, you know how Nikki
all of a sudden started...

Oh, no. Oh, sh... Is she okay?

Yes. She's-she's gonna be okay.

Why-why's Sarah texting me, man?

-She wants me to come over
to your place. -What?

She texted me over and over,
like, all this weird sh*t.

-f*ck.
-What's happening?

-Oh, f*ck.
-What the f*ck is happening?

-Okay, just stay here.
-[stammers] Is Nikki okay?

Do not... do not come over.

-Okay. -Bear! Bear,
tell me what the f*ck

-is happening right now!
-f*ck!

f*ck. Okay, okay, okay,
so Nikki...

she started liking me
out of nowhere,

all of a sudden,
and then acting weird.

Yes or no?

Bear, what the f*ck are you
gonna tell me right now, man?

-No. Ian, Ian.
-Is she okay?

I...

I made a wish.

I broke this piece of wood.
At first,

-I didn't think it was real.
-[sighs, mutters]

Okay? I was confused,
but this is real.

-This is f*cking real.
-What? What?

[sighs]

Okay, okay, okay.

You can make a wish, any...

You... you can make one wish,

and it is real and it will work.

I made a wish.
I-I didn't think it would work.

I wished that Nikki
would love me, but it worked.

Think about it, dude.

Think about how
she's been acting lately.

Think about how drastically
she changed.

Okay, what...
what did you take her to?

Like, a-a-a psychic?

-What?
-What?

What did...
What, did you do a f*cking...

-Uh, what program?
-No, no.

f*ck, there's not
a f*cking program, Ian.

You know, I don't know.
It's God f*cking magic.

Is this a joke to you?

No! This is real.

-This? This?
-Yes. Be careful.

Yes, it's real.
It's f*cking real, Ian.

I made a wish,
and it's f*cking horrible.

Then make another
f*cking wish, man.

No, you can't. You can't.

-Because you only get one wish.
-Oh, you only get one.

Oh, okay, yeah.

-That makes sense.
-One wish.

You only get one wish, Ian,
but it's real.

It's real, Ian.

So I need you to make a wish.

I need you to wish
that I never made a wish.

Okay?
And then you can be with Nikki.

[laughs]

Oh. Oh, so... so... so that...

-No, no, no. Dude, no.
-That's what this is about?

I don't even give a f*ck
about that, dude.

-I was gonna tell you.
-Seriously, just open the box,

and then just be careful
about how you word it.

-Whoa, whoa, whoa, whoa, whoa.
-[ominous melody playing]

Dude, stop.
Okay, um, I need you to say,

uh, uh, "I-I wish
for my friend Baron..."

I wish for a billion dollars.

-[melody ends]
-[screaming]: No!

♪ ♪

BEAR:
Nikki?

I need you to do
something for me.

[quiet, jazzy music playing]

♪ I do miss you ♪

♪ I do miss you,
I do miss you... ♪

Nikki, you'll do anything
for me, right?

[ominous melody playing
over tinny speakers]

-I need you...
-[melody ends]

♪ ♪

NIKKI: I'll do everything
for you, baby.

You like me better now?

[taking deep, sharp breaths]

Nikki, I need you... I need you
to do something for me, okay?

Why can't you love me?!

Stop.

Why don't you love me?!

-Stop! Stop!
-[Nikki yells]

Oh, God.

-God, I want to eat you up.
-Nikki.

-[knocking at door]
-IAN: Bear, open the door.

I got, like, a billion dollars,
dude. It's real.

-[Nikki whimpering, muttering]
-[knocking continues]

-Stop! Stop!
-BEAR: Nikki.

IAN:
Bear, what's going on?

-BEAR: Oh, God.
-I want to smell like you.

-BEAR: Nikki! No!
-IAN: I'm coming in.

You guys better not be doing
some weird sh*t!

-I just need you...
-IAN: I'm coming in!

-Whoa, whoa, whoa. Whoa, Nikki.
-I'll k*ll myself, Bear!

-What the... what the f*ck?
-I'll k*ll myself

-right in front of you!
-Nikki, what the f*ck?

-IAN: Nikki!
-[g*nsh*t]

NIKKI: I'll rip my eyes out
of my f*cking skull

and shove the barrel
in my p*ssy, Bear!

[Nikki retching]

[panting]:
I love you. I love you.

-Scream it!
-I love you. I love you!

[panting]

I knew you did.

Oh, I knew you did.

-I love you so much, baby.
-[breathing heavily]

-You owe me that.
-It's okay, baby.

-We're gonna make this work.
-You owe me that.

-I'll make this work.
-You have to, baby.

-I will, baby.
-I'm gonna heal.

-I'm gonna make this work.
-You have to.

I will.

I'm sorry for the theatrics.

I don't know why I do that.

-It's okay, sweetie.
-I love you.

-I love you so much.
-I'm gonna heal.

Uh-huh. Oh, I'm sorry.

It's okay, baby.

[crying]:
I'm gonna be pretty again.

-You're so beautiful.
-[whimpers]

You're the most beautiful girl
in the entire world.

-Yeah?
-Yeah, baby.

Oh, we are gonna be
together forever

and ever...

and ever and ever.

[Bear's breath trembling]

What?

What's wrong, baby?

You shook your head.

No, I didn't.

Why'd you shake your head?

I was just thinking that, uh,
we should freshen up, maybe.

-Okay?
-Okay.

Let's go. Come on.

I know what you want.

-NIKKI: No! f*ck you!
-[banging at door]

-f*ck you!
-[Bear breathing heavily]

-No!
-[banging at door continues]

Just give me a second
to freshen up.

-Let me in!
-I'm sorry!

-No! No!
-Babe, I just need a second!

-f*ck you, Bear! Let me in!
-[doorknob rattling]

[banging at door continues]

Bear, what are you doing?

-Just one second!
-Okay. Thank you.

-[banging stops]
-[Bear panting, whimpering]

Oh, sh*t.

Hey, baby?

NIKKI: I was thinking maybe
we should break up.

♪ ♪

Oh, sh*t.

You hear that?

f*ck. f*ck.

Baby, maybe we should
take some space.

If space is what we need,
then take it.

[panting]:
Oh, f*ck. f*ck.

NIKKI:
It's gonna be okay.

You hear that?

♪ ♪

We can take space.

We can take space.

Baby?

[gags quietly]

You hear that?

[breathing heavily]

♪ ♪

[ominous melody playing
over tinny speakers]

-[wood snaps]
-[melody ends]

♪ ♪

♪ ♪

♪ ♪

♪ ♪

[Bear's breath trembling]

NIKKI:
No, honey.

Honey, honey.

No, no, no.

-Bear! No.
-[labored breathing]

What did you do, Bear? No!

Baby, what did you do?
Baby, what did you do?

No!

[sobbing]:
No, no, no, no, no, no!

[wailing cry]

Baby.

Baby.

[stops crying, gasps]

[g*n drops to floor]

[whimpers]

[sobbing]

[body thuds on floor]

[whimpering]

["Forever" by
The Little Dippers playing]

[sobbing]

[sobbing continues]

[sobbing]:
What did you do?

♪ Hold me ♪

♪ Kiss me ♪

♪ Whisper ♪

♪ Sweetly ♪

♪ That you ♪

♪ Love me ♪

♪ Forever ♪

[sobbing continues]

[singers vocalizing]

[sobbing continues]

[singers continue vocalizing]

♪ Forever ♪

♪ Oh, oh ♪

♪ Hold me ♪

♪ Kiss me ♪

♪ Whisper ♪

♪ Sweetly ♪

♪ That you ♪

♪ Love me ♪

♪ Forever. ♪

[song ends]

♪ ♪

♪ ♪

[music fades]